"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const JSON5 = require("json5");
const path = require("path");
exports.isURI = path => !!path.match(/\w+:(\/?\/?)[^\s]+/);
exports.loadFile = (context, filePath) => {
    const { filesystem } = context;
    if (filesystem.exists(filePath) === 'file') {
        return JSON5.parse(filesystem.read(filePath));
    }
    else if (filesystem.exists(filePath + path.sep + '.solidarity')) {
        return JSON5.parse(filesystem.read(filePath + path.sep + '.solidarity'));
    }
    else if (filesystem.exists(filePath + path.sep + '.solidarity.json')) {
        return JSON5.parse(filesystem.read(filePath + path.sep + '.solidarity.json'));
    }
    else {
        throw 'ERROR: There is no solidarity file at the given path';
    }
};
exports.loadModule = (context, moduleName) => {
    const { filesystem } = context;
    // We will search that module
    const filePath = path.join('node_modules', moduleName, '.solidarity');
    if (filesystem.exists(filePath)) {
        return JSON5.parse(filesystem.read(filePath));
    }
    else if (filesystem.exists(filePath + '.json')) {
        return JSON5.parse(filesystem.read(filePath + '.json'));
    }
    else {
        throw 'ERROR: There is no solidarity file found with the given module';
    }
};
exports.loadWebCheck = (context, checkOption) => __awaiter(void 0, void 0, void 0, function* () {
    const { print, http, parameters } = context;
    const { options } = parameters;
    const silentMode = options.silent || options.s;
    const moderateMode = options.moderate || options.m;
    const checkSpinner = silentMode || moderateMode ? null : print.spin(`Running check on ${checkOption}`);
    // the base URL is throw away, and will go away in next version of apisauce
    const api = http.create({
        baseURL: 'https://api.github.com',
        timeout: 10000,
    });
    // Load check from web
    const checkURL = exports.isURI(checkOption)
        ? checkOption
        : `https:\/\/raw.githubusercontent.com/infinitered/solidarity-stacks/master/stacks/${checkOption}.solidarity`;
    const result = yield api.get(checkURL);
    // console.log(result)
    if (result.ok) {
        checkSpinner && checkSpinner.succeed(`Found Stack: ${checkOption}`);
        // Convert strings to JSON5 objects
        const solidarityData = typeof result.data === 'string' ? JSON5.parse(result.data) : result.data;
        return solidarityData;
    }
    else {
        checkSpinner && checkSpinner.fail(`Unable to find a known tech stack for ${checkOption}`);
        if (!silentMode) {
            print.info(`Check https://github.com/infinitered/solidarity-stacks for options.`);
        }
        throw `ERROR: Request failed (${result.status} - ${result.problem})`;
    }
});
module.exports = {
    isURI: exports.isURI,
    loadFile: exports.loadFile,
    loadModule: exports.loadModule,
    loadWebCheck: exports.loadWebCheck,
};
//# sourceMappingURL=getSolidarityHelpers.js.map