"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
// Get the version of a specific CLI
module.exports = (rule, context) => __awaiter(void 0, void 0, void 0, function* () {
    const { system, solidarity } = context;
    let versionOutput;
    // They specified how to check version
    if (rule.version) {
        versionOutput = yield system.run(`${rule.binary} ${rule.version}`);
        if (versionOutput === '') {
            // Lets try again
            // things like python and java use stderr instead of stdout
            const checkSTDERR = require('./checkSTDERR');
            versionOutput = yield system.run(checkSTDERR(rule, context));
        }
    }
    else {
        // We try the following in this order
        // -v, --version, -version, version
        try {
            versionOutput = yield system.run(`${rule.binary} -v`);
        }
        catch (_e) {
            try {
                versionOutput = yield system.run(`${rule.binary} --version`);
            }
            catch (_e) {
                try {
                    versionOutput = yield system.run(`${rule.binary} -version`);
                }
                catch (_e) {
                    try {
                        versionOutput = yield system.run(`${rule.binary} version`);
                    }
                    catch (_e) {
                        throw 'No version identifier flag for this binary was found';
                    }
                }
            }
        }
    }
    // Now parse
    const correctLine = solidarity.getLineWithVersion(rule, versionOutput);
    const version = solidarity.removeNonVersionCharacters(rule, correctLine);
    return version;
});
//# sourceMappingURL=getVersion.js.map