"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
module.exports = (context) => __awaiter(void 0, void 0, void 0, function* () {
    const { map, toPairs, isEmpty, flatten } = require('ramda');
    const { solidarity, print, strings } = context;
    const { pluralize } = strings;
    const { getSolidaritySettings, setSolidaritySettings, updateRequirement } = solidarity;
    // load current solidarity file
    const solidaritySettings = yield getSolidaritySettings(context);
    // Map over requirements with option to mutate settings
    const checks = yield map((requirement) => __awaiter(void 0, void 0, void 0, function* () { return updateRequirement(requirement, solidaritySettings.requirements, context); }), toPairs(solidaritySettings.requirements));
    // run the array of promises you just created
    try {
        const results = yield Promise.all(checks);
        const updates = flatten(results);
        if (isEmpty(updates)) {
            print.success('\n No Changes');
        }
        else {
            setSolidaritySettings(solidaritySettings, context);
            const ruleMessage = pluralize('Rule', updates.length, true);
            print.success(`\n ${ruleMessage} updated`);
        }
    }
    catch (err) {
        print.error(err);
        process.exit(2);
    }
});
//# sourceMappingURL=updateVersions.js.map